@@ -186,12 +186,12 @@ class Statement(Workflow, ModelSQL, ModelView):
 
     def search_rec_name(self, name, clause):
         ids = self.search(['OR',
-            ('start_balance',) + clause[1:],
-            ('end_balance',) + clause[1:],
+            ('start_balance',) + tuple(clause[1:]),
+            ('end_balance',) + tuple(clause[1:]),
             ])
         if ids:
             return [('id', 'in', ids)]
-        return [('journal',) + clause[1:]]
+        return [('journal',) + tuple(clause[1:])]
 
     def get_move_lines(self, ids, name):
         '''
@@ -469,6 +469,14 @@ class Line(ModelSQL, ModelView):
                 res['invoice'] = None
         return res
 
+    def copy(self, ids, default=None):
+        if default is None:
+            default = {}
+        default = default.copy()
+        default.setdefault('move', None)
+        default.setdefault('invoice', None)
+        return super(Line, self).copy(ids, default=default)
+
     def create_move(self, line):
         '''
         Create move for the statement line and return move id if created.
